@@ -103,7 +103,8 @@ def create_pipeline(checkout_url: str, screwdriver_api_url: str, token: str, sou
     :param screwdriver_api_url:  The URL of the Screwdriver API server
     :param token:  The Screwdriver API token
     :param source_directory:  The custom directory that this pipeline is based upon. See
-    https://qubitpi.github.io/screwdriver-cd-guide/user-guide/configuration/sourceDirectory for more details
+    `Source Directory <https://qubitpi.github.io/screwdriver-cd-guide/user-guide/configuration/sourceDirectory>`_
+     for more details
 
     :return: the native API response body object with the following fields:
 
